#
# spec file for package libjaylink
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libjaylink
Version:        0.3.1
Release:        1.9
URL:            https://gitlab.zapb.de/libjaylink/libjaylink.git
Summary:        USB interface library for J-Link
License:        GPL-2.0-or-later
Group:          Development/Tools/Debuggers
Source:         libjaylink-%{version}.tar.xz
BuildRequires:  autoconf >= 2.64
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post): udev
Requires(postun):udev
%define _udevdir %(pkg-config --variable udevdir udev)
Provides:       libjaylink0:%{_udevdir}/rules.d/99-libjaylink.rules

%description
Library for accessing Segger J-Link USB devices.

%package -n libjaylink0
Summary:        USB interface library for J-Link
Group:          System/Libraries
Recommends:     libjaylink

%description -n libjaylink0
Library for accessing Segger J-Link USB devices.

%package devel
Summary:        USB interface library for J-Link -- development files
Group:          Development/Libraries/C and C++
Requires:       libjaylink0 = %{version}

%description devel
Library for accessing Segger J-Link USB devices.

This sub-package contains the development files.

%prep
%setup -q

%build
./autogen.sh
%configure --disable-static
make %{?_smp_mflags}

%install
make %{?_smp_mflags} install DESTDIR=%{buildroot}
rm -f %{buildroot}%{_libdir}/libjaylink.la
mkdir -p %{buildroot}%{_udevdir}/rules.d
sed -e 's/GROUP="plugdev"/GROUP="users"/' <contrib/99-libjaylink.rules >%{buildroot}%{_udevdir}/rules.d/99-libjaylink.rules

%post
%udev_rules_update

%postun
%udev_rules_update

%post -n libjaylink0 -p /sbin/ldconfig

%postun -n libjaylink0 -p /sbin/ldconfig

%files
%license COPYING
%{_udevdir}/rules.d/99-libjaylink.rules

%files -n libjaylink0
%{_libdir}/libjaylink.so.0*

%files devel
%{_includedir}/libjaylink/
%{_libdir}/libjaylink.so
%{_libdir}/pkgconfig/libjaylink.pc

%changelog
* Wed Feb  8 2023 Torsten Gruner <simmphonie@opensuse.org>
- Update to version 0.3.1
  * Fix building with Autoconf < 2.7
- version 0.3.0
  * New package version scheme
  * New supported target interfaces:
  - Silicon Labs 2-wire interface (C2)
  - Serial peripheral interface (SPI)
  - Compact JTAG (cJTAG)
  * Add support for querying USB voltage
  * jtag: Add functions to set/clear the TCK and TMS signals
  * New string utility functions:
  - jaylink_target_interface_string()
  - jaylink_hardware_type_string()
  * transport/tcp: Implement connection timeout
* Fri Feb 26 2021 Philipp Wagner <mail@philipp-wagner.com>
- Update to upstream version 0.2.0
  * Initial support for TCP/IP devices
  * libusb is now optional
  * configure: Add switch to build without libusb
  * configure: Show enabled transports
  * Support for various new USB product IDs
  * Fix build issue with MSYS2
  * Fix socket timeouts on Windows
  * Make library C++ compatible
  * New log level for I/O debug messages
  * Add function to get USB bus and port numbers of a device
  * Add function to retrieve counter values
- Update repository URL
- Switch from obs_scm to obs_tar for disabled service, as the additional
  tar service seems unavailable these days.
* Thu Dec 28 2017 afaerber@suse.de
- Update to latest Git snapshot (8645845c1abebd004e991ba9a7f808f4fd0c608b)
* Thu Dec 28 2017 afaerber@suse.de
- Update to 0.1.0 tag
* Sun Dec 11 2016 afaerber@suse.de
- Update to latest Git snapshot (8f3e9d47fc4818a25ca95440e82a18a514447ee)
* Wed Oct 19 2016 afaerber@suse.de
- Update to latest Git snapshot (faa2a433fdd3de211728f3da5921133214af9dd3)
* Sun Jun 19 2016 jengelh@inai.de
- Reset RPM groups
* Thu May 12 2016 afaerber@suse.de
- Switch to new service obs_scm
* Thu May 12 2016 afaerber@suse.de
- Update to latest Git snapshot (d57dee67bc756291b7d8b51d350d1c6213e514f0)
  * Relax autoconf requirement (follows configure.ac change)
- Disable services in preparation for Factory
* Tue Feb 16 2016 afaerber@suse.de
- Change version scheme to include date rather that commit hash
- Update to latest Git snapshot (200f6a1e692b6a530e2dd5f82f686b6be661be45)
* Sun Nov 29 2015 afaerber@suse.de
- Fix %%post and %%postun
  * Move udev rules to base libjaylink package
- Add _service for automating updates from Git
  * This changes the version/release scheme slightly
- Update to latest master
  * Includes workaround for reading serial number on old devices
* Sun Oct 25 2015 afaerber@suse.de
- Initial
